#
# spec file for package perl-Net-CIDR
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Net-CIDR
Name:           perl-Net-CIDR
Version:        0.260.0
Release:        1.1
# 0.26 -> normalize -> 0.260.0
%define cpan_version 0.26
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Manipulate IPv4/IPv6 netblocks in CIDR notation
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MR/MRSAM/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 1
Provides:       perl(Net::CIDR) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
The Net::CIDR package contains functions that manipulate lists of IP
netblocks expressed in CIDR notation. The Net::CIDR functions handle both
IPv4 and IPv6 addresses.

The cidrvalidate() function, described below, checks that its argument is a
single, valid IP address or a CIDR. The remaining functions expect that
their parameters consist of validated IPs or CIDRs. See cidrvalidate() and
BUGS, below, for more information.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ChangeLog README
%license COPYING

%changelog
* Sat Jun 21 2025 Tina Müller <timueller+perl@suse.de>
- updated to 0.260.0 (0.26)
  see /usr/share/doc/packages/perl-Net-CIDR/ChangeLog
  0.26    Sam Varshavchik  <mrsam@courier-mta.com>
  cidrvalidate() should accept IPv6 addresses with one uncompressed
  0.
* Sat May 24 2025 Tina Müller <timueller+perl@suse.de>
- updated to 0.250.0 (0.25)
  see /usr/share/doc/packages/perl-Net-CIDR/ChangeLog
  0.25    Sam Varshavchik  <mrsam@courier-mta.com>
  Fix warning with Perl 5.40
  0.24.1
  No changes, re-pushed due to a release problem.
  0.24
  2025-03-09   brian d foy <briandfoy@pobox.com>
  * Strip leading zeros from octets from addr2cidr
* Tue Mar 11 2025 Tina Müller <timueller+perl@suse.de>
- updated to 0.230.0 (0.23)
  see /usr/share/doc/packages/perl-Net-CIDR/ChangeLog
  0.23
  2025-03-09   brian d foy <briandfoy@pobox.com>
  * Allow unabbreviated IPv6 addresses.
  0.22
  2025-03-09  Sam Varshavchik  <mrsam@courier-mta.com>
  * Improve several error messages.
  2025-03-09   brian d foy <briandfoy@pobox.com>
  * Allow unabbreviated IPv6 addresses.
* Wed Mar 31 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.21
  see /usr/share/doc/packages/perl-Net-CIDR/ChangeLog
  0.21
  2021-03-30  Sam Varshavchik  <mrsam@courier-mta.com>
  * Update perldoc to emphasize proper usage of ciddrvalidate().
* Wed Apr 17 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.20
  see /usr/share/doc/packages/perl-Net-CIDR/ChangeLog
  0.20
  2019-04-16  Sam Varshavchik  <mrsam@courier-mta.com>
  * _ipcmp: handle comparison of mixed IPv4 and IPv6-specified
  addresses, allowing cidrlookup() to look up IPv6-mapped IPv4 addresses
  in IPv4 address ranges, and vice versa.
* Wed Jun 13 2018 coolo@suse.com
- updated to 0.19
  see /usr/share/doc/packages/perl-Net-CIDR/ChangeLog
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.18
  see /usr/share/doc/packages/perl-Net-CIDR/Changes
  0.15 Thu Feb 16 08:09:45 EST 2012
  - corrected cidrvalidate() to return values according to its
    documentation, in some corner cases.
  0.16 Sat Sep 29 09:29:43 EDT 2012
  - cidrvalidate() corrects octet-shortchanged IPv4 addresses to their
    proper size.
  0.17 Sat Oct 20 23:21:18 EDT 2012
  - version bump, put META back into the tarball.
  0.18 Mon Feb  2 18:12:54 EST 2015
  - leading 0s in IPv6 addresses are ok.
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Thu Aug 26 2010 pascal.bleser@opensuse.org
- initial package (0.14)
